@@ -234,8 +234,8 @@ class IntervalButtonsWidget(gtk.Table, cfg.ConfigUtils):
         self.new_int_button(_("Perfect\noctave"),   12, 2, 3, 6, 8)
         self.new_int_button(_("Minor\nninth"),  13, 3, 4, 0, 2)
         self.new_int_button(_("Major\nninth"),   14, 3, 4, 2, 4)
-        self.new_int_button(_("Minor\ndecim"), 15, 3, 4, 4, 6)
-        self.new_int_button(_("Major\ndecim"),  16, 3, 4, 6, 8)
+        self.new_int_button(_("Minor\ntenth"), 15, 3, 4, 4, 6)
+        self.new_int_button(_("Major\ntenth"),  16, 3, 4, 6, 8)
         self.m_lowest_tone = mpd.LOWEST_NOTENAME
         self.m_highest_tone = mpd.HIGHEST_NOTENAME
         self.add_watch('disable_unused_intervals', self.intervals_changed)
